@@ -1,7 +1,6 @@
 # $Author: ddumont $
 # $Date: 2008-01-23 11:12:16 $
-# $Name: not supported by cvs2svn $
-# $Revision: 1.5 $
+# $Revision$
 
 #    Copyright (c) 2005,2006 Dominique Dumont.
 #
@@ -32,7 +31,7 @@ use Data::Dumper ;
 
 use vars qw($VERSION) ;
 
-$VERSION = sprintf "%d.%03d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf "1.%04d", q$Revision: 711 $ =~ /(\d+)/;
 
 my $logger = Log::Log4perl::get_logger(__PACKAGE__);
 
@@ -48,12 +47,14 @@ sub read {
     my $dir = join('/',$root,$conf_dir) ;
 
     unless (-d $dir ) {
-	croak __PACKAGE__," read: unknown config dir $dir";
+	warn __PACKAGE__," read: unknown config dir $dir";
+	return 0;
     }
 
     my $file = "$dir/xorg.conf" ;
     unless (-r "$file") {
-	croak __PACKAGE__," read: unknown file $file";
+	warn __PACKAGE__," read: unknown file $file";
+	return 0;
     }
 
     my $i = $config_root->instance ;
@@ -78,6 +79,7 @@ sub read {
 	#print Dumper($data); exit ;
 
 	parse_all($data, $config_root) ;
+	return 1 ;
     }
     else {
 	die __PACKAGE__," read: can't open $file:$!";
@@ -118,6 +120,8 @@ sub parse_raw_section {
     my $xorg_lines = shift ;
 
     my %data ;
+    $logger->debug( "parse_raw_section: called");
+
     while (@$xorg_lines) {
 	my $line_data = shift @$xorg_lines ;
 	my ($line_nb,$line) = @$line_data ;
@@ -189,31 +193,31 @@ sub parse_option {
     my $opt = shift @args;
 
     if ($obj->config_class_name eq 'Xorg::ServerFlags') {
-	$logger->debug( "obj ",$obj->name, " ($line) load option '$opt' ");
+	$logger->debug( "parse_option: obj ",$obj->name, " ($line) load option '$opt' ");
 	my $opt_obj = $obj->fetch_element($opt) ;
 	$opt_obj->store ( @args  ? $args[0] : 1 ) ;
     }
     elsif ($opt =~ /Core(Keyboard|Pointer)/ ) {
 	my $id = $obj -> index_value ;
-	$logger->debug( "($line) Load top level $opt to '$id'");
+	$logger->debug( "parse_option: ($line) Load top level $opt to '$id'");
 	$obj->load( qq(! $opt="$id") ) ;
     }
     elsif (    $obj->config_class_name eq 'Xorg::InputDevice' 
 	   and $opt eq 'AutoRepeat') {
-	$logger->debug( "obj ",$obj->name, " ($line) load option '$opt' with '",
+	$logger->debug( "parse_option: obj ",$obj->name, " ($line) load option '$opt' with '",
 			join('+',@args),"' ");
 	my @v = split / /,$args[0] ;
 	my $load = sprintf ( "Option AutoRepeat delay=%s rate=%s", @v);
-	$logger->debug( $obj->name," load '$load'");
+	$logger->debug( "parse_option: ",$obj->name," load '$load'");
 	$obj->load($load) ;
     }
     elsif (     $obj->config_class_name eq 'Xorg::InputDevice'
 	    and $opt eq 'XkbOptions' ) {
-	$logger->debug( "obj ",$obj->name, " ($line) load option '$opt' with '",
+	$logger->debug( "parse_option: obj ",$obj->name, " ($line) load option '$opt' with '",
 			join('+',@args),"' ");
 	my @v = split /:/,$args[0] ;
 	my $load = sprintf ( "Option XkbOptions %s=%s", @v);
-	$logger->debug( $obj->name," load '$load'");
+	$logger->debug( "parse_option: ",$obj->name," load '$load'");
 	$obj->load($load) ;
     }
     else {
@@ -221,7 +225,7 @@ sub parse_option {
 	my $opt_p_obj = $obj->fetch_element("Option") ;
 	my $opt_obj;
 	if ($opt_p_obj->has_element($opt)) {
-	    $logger->debug( "obj ",$obj->name, " ($line) load option '$opt' ");
+	    $logger->debug( "parse_option: obj ",$obj->name, " ($line) load option '$opt' ");
 	    $opt_obj= $opt_p_obj->fetch_element($opt) ;
 	    $opt_obj->store ( @args  ? $args[0] : 1 ) if defined $opt_obj ;
 	}
@@ -234,7 +238,7 @@ sub parse_option {
 			);
 	}
 	else {
-	    $logger->warn( "obj ",$obj->name, " ($line) option '$opt' is unknown");
+	    $logger->warn( "parse_option: obj ",$obj->name, " ($line) option '$opt' is unknown");
 	}
     }
 }
@@ -261,7 +265,7 @@ sub parse_mode_line {
     $load .= "Flags " . join (' ', map {$mode_flags{$_} || "$_=1" } @m ) . ' - ' 
       if @m ;
 
-    $logger->debug( "($line) load '$load'");
+    $logger->debug( "parse_mode_line: ($line) load '$load'");
     $obj->load($load) ;
 }
 
@@ -269,7 +273,7 @@ sub parse_modes_list {
     my ($obj, $trash, $line_nb, @modes) = @_ ;
 
     my $load = "Modes=".join(',',@modes);
-    $logger->debug( "($line_nb))load '$load'");
+    $logger->debug( "parse_modes_list: ($line_nb))load '$load'");
     $obj->load($load) ;
 }
 
@@ -296,7 +300,7 @@ sub parse_layout_screen {
 
 	$load = "Screen:$num screen_id=\"$screen_id\" ";
 
-	$logger->debug( "Screen load '$load'");
+	$logger->debug( "parse_layout_screen: screen load '$load'");
 
 	if (@args) {
 	    # there's a position information
@@ -320,10 +324,10 @@ sub parse_layout_screen {
 	    }
 	    $load .= "position relative_screen_location=$pos $relative_spec ";
 	}
-	$logger->debug( "Screen ($line) load '$load' ");
+	$logger->debug( "parse_layout_screen: Screen ($line) load '$load' ");
     }
 
-    $logger->debug( $obj->config_class_name," load '$load'");
+    $logger->debug( "parse_layout_screen:", $obj->config_class_name," load '$load'");
     $obj->load($load) ;
 }
 
@@ -340,7 +344,7 @@ sub parse_input_device {
 	    $dev->fetch_element($opt)->store(1) ;
 	}
 	elsif ($opt =~ /Core(Keyboard|Pointer)/) {
-	    $logger->debug( "Load '! $opt=\"$id\"'");
+	    $logger->debug( "parse_input_device: Load '! $opt=\"$id\"'");
 	    $obj->load("! $opt=\"$id\"") ;
 	}
 	else {
